board_classic: Is the board using classic game mode?
Description
In classic mode, pressing a light will toggle it and its adjacent neighbours only.
If non-classic mode, pressing a light will toggle the entire row and column of the pressed light.
Usage
board_classic(board)
Arguments
board
A lightsout board object